# Magic value specification utilities

[![Coverage Status][coverage-badge]][coverage]
[![GitHub Workflow Status][status-badge]][status]
[![PyPI][pypi-badge]][pypi]
[![GitHub][licence-badge]][licence]
[![GitHub Last Commit][repo-badge]][repo]
[![GitHub Issues][issues-badge]][issues]
[![Python Version][version-badge]][pypi]

```shell
pip install magic-specs
```

---

**Documentation**: [https://mrthearman.github.io/magic-specs/](https://mrthearman.github.io/magic-specs/)

**Source Code**: [https://github.com/MrThearMan/magic-specs/](https://github.com/MrThearMan/magic-specs/)

---


This library contains utilities for making definitions for magic values.


[coverage-badge]: https://coveralls.io/repos/github/MrThearMan/magic-specs/badge.svg?branch=main
[status-badge]: https://img.shields.io/github/workflow/status/MrThearMan/magic-specs/Tests
[pypi-badge]: https://img.shields.io/pypi/v/magic-specs
[licence-badge]: https://img.shields.io/github/license/MrThearMan/magic-specs
[repo-badge]: https://img.shields.io/github/last-commit/MrThearMan/magic-specs
[issues-badge]: https://img.shields.io/github/issues-raw/MrThearMan/magic-specs
[version-badge]: https://img.shields.io/pypi/pyversions/magic-specs

[coverage]: https://coveralls.io/github/MrThearMan/magic-specs?branch=main
[status]: https://github.com/MrThearMan/magic-specs/actions/workflows/main.yml
[pypi]: https://pypi.org/project/magic-specs
[licence]: https://github.com/MrThearMan/magic-specs/blob/main/LICENSE
[repo]: https://github.com/MrThearMan/magic-specs/commits/main
[issues]: https://github.com/MrThearMan/magic-specs/issues